@@ -2,7 +2,7 @@
 #define APPLICATIONVIEW_H
 
 #include <QWidget>
-#include <rx/columbus/ColumbusController.h>
+#include "ApplicationController.h"
 
 class ApplicationView : public QWidget
 {
@@ -15,7 +15,7 @@ public:
 
     virtual QString      friendlyName       () const = 0;
 
-    virtual void         setController      (ColumbusController *controller) = 0;
+    virtual void         setController      (ApplicationController *controller) = 0;
 
     /*
     virtual void         suspend            () = 0;
