@@ -1,7 +1,7 @@
 #ifndef APPLICATIONVIEWSWITCHER_H
 #define APPLICATIONVIEWSWITCHER_H
 
-#include "widgets/DraggableViewArea.h"
+#include <rx/widgets/DraggableViewArea.h>
 #include "ApplicationView.h"
 
 class ApplicationViewSwitcherPrivate;
