@@ -14,7 +14,7 @@ public:
             ~ColumbusDialogLogging();
 
 public slots:
-    void setController(ColumbusController *controller);
+    void setController(ApplicationController *controller);
 
 protected slots:
     void setupUi();
