@@ -9,7 +9,7 @@
 class ColumbusStatisticsViewPrivate
 {
 public:
-    ColumbusController *controller;
+    ApplicationController *controller;
 
     QFormLayout *details;
 
@@ -54,11 +54,11 @@ ColumbusStatisticsView::ColumbusStatisticsView(QWidget *parent)
 
 QString ColumbusStatisticsView::friendlyName() const
 {
-    static const QString friendlyName = QString("Statistics");
+    static const QString friendlyName = "Statistics";
     return friendlyName;
 }
 
-void ColumbusStatisticsView::setController(ColumbusController *controller)
+void ColumbusStatisticsView::setController(ApplicationController *controller)
 {
     if(d->controller != NULL)
     {
