@@ -3,7 +3,6 @@
 
 #include "ApplicationView.h"
 
-#include <QString>
 #include <QLabel>
 
 class ColumbusStatusViewPrivate;
@@ -18,8 +17,8 @@ public:
 
     QString                  friendlyName       () const;
 
-    ColumbusController*      controller         () const;
-    void                     setController      (ColumbusController *controller);
+    ApplicationController*      controller         () const;
+    void                     setController      (ApplicationController *controller);
 
 private slots:
     void         onLandscape                ();
