@@ -2,6 +2,7 @@
 #include <QtDBus>
 
 #include "config.h"
+#include <rx/columbus/config.h>
 
 #include <rx/widgets/Maemo5TaskButton.h>
 #include <rx/widgets/Maemo5MenuButton.h>
@@ -24,27 +25,27 @@
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent)
 {
-    m_ScreenSaver                   = NULL;
-    m_Controller                    = NULL;
-    m_ControllerSuspended           = NULL;
-    m_ViewsActionGroup              = NULL;
+    m_ScreenSaver               = NULL;
+    m_Controller                = NULL;
+    m_ControllerSuspended       = NULL;
+    m_ViewsActionGroup          = NULL;
 
-    m_ScreenLockState               = "unlocked";
+    m_ScreenLockState           = "unlocked";
 
-    m_WaypointsDialog               = new ColumbusDialogWaypoints(this);
-    m_LoggingDialog                 = new ColumbusDialogLogging(this);
-    m_OptionsDialog                 = new ColumbusDialogOptions(this);
-    m_ToolsDialog                   = new ColumbusDialogTools(this);
+    m_WaypointsDialog           = new ColumbusDialogWaypoints(this);
+    m_LoggingDialog             = new ColumbusDialogLogging(this);
+    m_OptionsDialog             = new ColumbusDialogOptions(this);
+    m_ToolsDialog               = new ColumbusDialogTools(this);
 
-    m_ControlsAnimationGroup        = new QParallelAnimationGroup(this);
+    m_ControlsAnimationGroup    = new QParallelAnimationGroup(this);
 
-    Maemo5TaskButton *tBtn          = new Maemo5TaskButton(this);
-    Maemo5MenuButton *mBtn          = new Maemo5MenuButton(this);
-    Maemo5FullScreenButton *fBtn    = new Maemo5FullScreenButton(this);
+    QToolButton *tBtn           = new Maemo5TaskButton(this);
+    QToolButton *mBtn           = new Maemo5MenuButton(this);
+    QToolButton *fBtn           = new Maemo5FullScreenButton(this);
 
-    QPropertyAnimation *tAnim       = new QPropertyAnimation(tBtn, "geometry", this);
-    QPropertyAnimation *mAnim       = new QPropertyAnimation(mBtn, "geometry", this);
-    QPropertyAnimation *fAnim       = new QPropertyAnimation(fBtn, "geometry", this);
+    QPropertyAnimation *tAnim   = new QPropertyAnimation(tBtn, "geometry", this);
+    QPropertyAnimation *mAnim   = new QPropertyAnimation(mBtn, "geometry", this);
+    QPropertyAnimation *fAnim   = new QPropertyAnimation(fBtn, "geometry", this);
 
     tAnim->setDuration(750);
     mAnim->setDuration(tAnim->duration());
@@ -60,12 +61,15 @@ MainWindow::MainWindow(QWidget *parent)
     this->setupPalettes();
 
     this->installEventFilter(this);
+
     QTimer::singleShot(1000, this, SLOT(hideFullScreenControls()));
 
     tBtn->raise();
     mBtn->raise();
     fBtn->raise();
 
+    QObject::connect(m_ControlsAnimationGroup, SIGNAL(finished()), this, SLOT(onAnimationFinished()));
+
 #if defined(Q_WS_MAEMO_5)
     QObject::connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(resized()));
 #endif
@@ -162,6 +166,8 @@ void MainWindow::showFullScreenControls()
     QWidget *mBtn = qobject_cast<QWidget*>(mAnim->targetObject());
     QWidget *fBtn = qobject_cast<QWidget*>(fAnim->targetObject());
 
+    if(m_ControlsAnimationGroup->state() == QPropertyAnimation::Running) return;
+
     tAnim->setEasingCurve(QEasingCurve::OutBounce);
     mAnim->setEasingCurve(tAnim->easingCurve());
     fAnim->setEasingCurve(tAnim->easingCurve());
@@ -192,6 +198,8 @@ void MainWindow::hideFullScreenControls()
     QWidget *mBtn = qobject_cast<QWidget*>(mAnim->targetObject());
     QWidget *fBtn = qobject_cast<QWidget*>(fAnim->targetObject());
 
+    if(m_ControlsAnimationGroup->state() == QPropertyAnimation::Running) return;
+
     tAnim->setEasingCurve(QEasingCurve::InQuad);
     mAnim->setEasingCurve(tAnim->easingCurve());
     fAnim->setEasingCurve(tAnim->easingCurve());
@@ -212,25 +220,50 @@ void MainWindow::hideFullScreenControls()
     m_ControlsAnimationGroup->start();
 }
 
+void MainWindow::onAnimationFinished()
+{
+}
+
 void MainWindow::resized()
 {
-    const QDesktopWidget *desktop = QApplication::desktop();
-    QPalette palette = this->palette();
+    QPropertyAnimation *tAnim = qobject_cast<QPropertyAnimation*>(m_ControlsAnimationGroup->animationAt(0));
+    QPropertyAnimation *mAnim = qobject_cast<QPropertyAnimation*>(m_ControlsAnimationGroup->animationAt(1));
+    QPropertyAnimation *fAnim = qobject_cast<QPropertyAnimation*>(m_ControlsAnimationGroup->animationAt(2));
 
+    QWidget *tBtn = qobject_cast<QWidget*>(tAnim->targetObject());
+    QWidget *mBtn = qobject_cast<QWidget*>(mAnim->targetObject());
+    QWidget *fBtn = qobject_cast<QWidget*>(fAnim->targetObject());
+
+    const QDesktopWidget *desktop = QApplication::desktop();
+
+    QPalette palette = this->palette();
     if(desktop->width() > desktop->height())
     {
         palette.setBrush(this->backgroundRole(), QBrush(QImage(":/MainWindowBG.png")));
+
+#if defined(Q_WS_MAEMO_5)
+        tBtn->move(0, -tBtn->height());
+        mBtn->move(800 - mBtn->width(), -mBtn->height());
+        fBtn->move(800 - fBtn->width(), 480);
+#endif
+
         emit this->onLandscape();
     }
     else
     {
         palette.setBrush(this->backgroundRole(), QBrush(QImage(":/MainWindowBG_Portrait.png")));
+
+#if defined(Q_WS_MAEMO_5)
+        tBtn->move(0, -tBtn->height());
+        mBtn->move(480 - mBtn->width(), -mBtn->height());
+        fBtn->move(480 - fBtn->width(), 800);
+#endif
+
         emit this->onPortrait();
     }
 
     this->setPalette(palette);
-
-    QTimer::singleShot(2000, this, SLOT(showFullScreenControls()));
+    this->hideFullScreenControls();
 }
 
 bool MainWindow::eventFilter(QObject *object, QEvent *event)
@@ -238,9 +271,10 @@ bool MainWindow::eventFilter(QObject *object, QEvent *event)
     switch(event->type())
     {
     case QEvent::MouseButtonPress:
-        this->showFullScreenControls();
         break;
+
     case QEvent::MouseButtonRelease:
+        this->showFullScreenControls();
         QTimer::singleShot(4000, this, SLOT(hideFullScreenControls()));
         break;
 
@@ -315,10 +349,10 @@ void MainWindow::setupMenu()
         gsAction->setCheckable(true);
     }
 
-    m_ViewsActionGroup->actions().at(CONFIG_DEFAULT_DISPLAY_VIEW)->setChecked(true);
+    m_ViewsActionGroup->actions().at(0)->setChecked(true);
     this->menuBar()->addActions(m_ViewsActionGroup->actions());
 
-    //this->menuBar()->addAction(tr("Waypoints"), m_WaypointsDialog, SLOT(show()));
+    this->menuBar()->addAction(tr("Waypoints"), m_WaypointsDialog, SLOT(showMaximized()));
     this->menuBar()->addAction(tr("Logging"), m_LoggingDialog, SLOT(show()));
     this->menuBar()->addAction(tr("Options"), m_OptionsDialog, SLOT(show()));
     this->menuBar()->addAction(tr("Tools"), m_ToolsDialog, SLOT(show()));
@@ -351,7 +385,7 @@ void MainWindow::setupPalettes()
 void MainWindow::onViewChanged(int view)
 {
     m_ViewsActionGroup->actions().at(view)->setChecked(true);
-    QTimer::singleShot(2000, this, SLOT(hideFullScreenControls()));
+    this->hideFullScreenControls();
 }
 
 void MainWindow::onViewsActionSelected(QAction *action)
@@ -359,7 +393,7 @@ void MainWindow::onViewsActionSelected(QAction *action)
     m_ApplicationViewSwitcher->slideTo(action->data().toInt());
 }
 
-void MainWindow::initialize(ColumbusController *controller)
+void MainWindow::initialize(ApplicationController *controller)
 {
     if(controller != NULL && m_ControllerSuspended == NULL) // On first initialization.
     {
