@@ -3,12 +3,19 @@
 
 namespace
 {
-    static const int BearingMarker[3][2] = {
+    static const int HeadingMarker[3][2] = {
         {-2, -1},
         {+2, -1},
         {+0, +1}
     };
 
+    static const int BearingMarker[4][2] = {
+        {-1,  0},
+        { 0,  1},
+        { 1,  0},
+        { 0, -1}
+    };
+
     static const char *CompassPoints[8] = {
         "N", "NE", "E", "SE", "S", "SW", "W", "NW"
     };
